==> pyside-setup-opensource-src-5.15.0.zip: pyside-setup-opensource-src-5.15.0/sources/shiboken2/tests/libother/otherobjecttype.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the test suite of Qt for Python.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "otherobjecttype.h"

Collector&
operator<<(Collector& collector, const OtherObjectType& obj)
{
    collector << obj.identifier()*2;
    return collector;
}

int OtherObjectType::enumAsInt(SampleNamespace::SomeClass::PublicScopedEnum value)
{
    return static_cast<int>(value);
}

int OtherObjectType::enumAsIntForInvisibleNamespace(Invisible::EnumOnNamespace value)
{
    return static_cast<int>(value);
}

==> pyside-setup-opensource-src-5.15.12.zip: pyside-setup-opensource-src-5.15.12/sources/shiboken2/tests/libother/otherobjecttype.cpp <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of the test suite of Qt for Python.
**
** $QT_BEGIN_LICENSE:GPL-EXCEPT$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "otherobjecttype.h"

Collector&
operator<<(Collector& collector, const OtherObjectType& obj)
{
    collector << obj.identifier()*2;
    return collector;
}

int OtherObjectType::enumAsInt(SampleNamespace::SomeClass::PublicScopedEnum value)
{
    return static_cast<int>(value);
}

int OtherObjectType::enumAsIntForInvisibleNamespace(RemovedNamespace1::RemovedNamespace1_Enum value)
{
    return static_cast<int>(value);
}
